<?php

namespace Drupal\commerce_chase\Event;

use Drupal\commerce_payment\Entity\PaymentMethodInterface;
use Symfony\Component\EventDispatcher\Event;

/**
 * Defines the Chase iframe query event.
 *
 * @see \Drupal\commerce_chase\Event\PaymentEvents
 */
class BuildIframeQueryEvent extends Event {

  /**
   * The payment method.
   *
   * @var \Drupal\commerce_payment\Entity\PaymentMethodInterface
   */
  protected $paymentMethod;

  /**
   * The url query array.
   *
   * @var array
   */
  protected $query;

  /**
   * Constructs a new PaymentEvent.
   *
   * @param \Drupal\commerce_payment\Entity\PaymentInterface $payment
   *   The payment.
   */
  public function __construct(array $query, PaymentMethodInterface $payment_method) {
    $this->paymentMethod = $payment_method;
    $this->query = $query;
  }

  /**
   * Gets the payment.
   *
   * @return \Drupal\commerce_payment\Entity\PaymentInterface
   *   The payment.
   */
  public function getPaymentMethod() {
    return $this->paymentMethod;
  }

  /**
   * Gets the url query array.
   *
   * @return array
   *   The url query array.
   */
  public function getQuery() {
    return $this->query;
  }

}
